webNotebook constant
Size
const webNotebook
Standard notebook resolution for testing responsive Web systems (1366x768).
Implementation
static const Size webNotebook = Size(1366, 768);
Standard notebook resolution for testing responsive Web systems (1366x768).
static const Size webNotebook = Size(1366, 768);