variant property
T
variant
final
The variant or configuration associated with this specific test scenario.
Implementation
final T variant;
The variant or configuration associated with this specific test scenario.
final T variant;