easy_variants library

Classes

MatrixVariant
A robust TestVariant combiner that builds a Cartesian product matrix out of multiple independent TestVariant instances.
TestDeviceVariant
A TestVariant that automates responsive and multi-platform widget testing by cycling through a matrix of simulated devices.
TestPlatformVariant
A TestVariant that automates multi-platform widget testing by cycling through a defined matrix of target operating systems (TargetPlatform).
TestScenarioVariant<T>
A TestVariant implementation that iterates over a set of TestScenarios.