values property
Returns an iterable of the variations that this test dimension represents.
The variations returned should be unique so that the same variation isn't needlessly run twice.
Implementation
@override
final Set<Map<TestVariant<dynamic>, dynamic>> values;