current property

DeviceVariantConfig get current

Retrieves the configuration of the device currently active in the running test slice.

Throws a state error if accessed outside the execution lifecycle of a test.

Implementation

DeviceVariantConfig get current => _current!;