setUp method
Configures the Flutter testing framework environment prior to running the test block.
Overrides debugDefaultTargetPlatformOverride and binds the implicit view's
physical size and pixel ratio to mirror the provided value blueprint.
Implementation
@override
Future<void> setUp(DeviceVariantConfig value) async {
_current = value;
debugDefaultTargetPlatformOverride = value.platform;
final binding = TestWidgetsFlutterBinding.ensureInitialized();
binding.platformDispatcher.implicitView?.physicalSize = value.size;
binding.platformDispatcher.implicitView?.devicePixelRatio = 1.0;
}