current property

TargetPlatform get current

Retrieves the operating system platform currently active in the running test slice.

Throws a StateError if accessed outside the execution lifecycle of an alive test.

Implementation

TargetPlatform get current => _current!;