describeValue method

  1. @override
String describeValue(
  1. TestScenario<T> value
)
override

Returns the string that will be used to both add to the test description, and be printed when a test fails for this variation.

Implementation

@override
String describeValue(TestScenario<T> value) {
  return value.description;
}