setUp method
Sets the current scenario before executing a test case.
Implementation
@override
Future<void> setUp(TestScenario<T> value) async {
_current = value;
}
Sets the current scenario before executing a test case.
@override
Future<void> setUp(TestScenario<T> value) async {
_current = value;
}