tearDown method
Clears the current scenario after the test case has finished.
Implementation
@override
Future<void> tearDown(
TestScenario<T> value,
covariant Object? memento,
) async {
_current = null;
}
Clears the current scenario after the test case has finished.
@override
Future<void> tearDown(
TestScenario<T> value,
covariant Object? memento,
) async {
_current = null;
}