tearDown method
Cleans up target environment modifications made during the setUp phase.
Reverts the target platform property to its original default testing state.
Implementation
@override
Future<void> tearDown(TargetPlatform value, covariant Object? memento) async {
_current = null;
debugDefaultTargetPlatformOverride = null;
}