TestScenarioVariant<T> class

Inheritance

Constructors

TestScenarioVariant(Set<TestScenario<T>> scenarios)

Properties

current TestScenario<T>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Set<TestScenario<T>>
Returns an iterable of the variations that this test dimension represents.
final

Methods

describeValue(TestScenario<T> value) String
Returns the string that will be used to both add to the test description, and be printed when a test fails for this variation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUp(TestScenario<T> value) Future<void>
A function that will be called before each value is tested, with the value that will be tested.
override
tearDown(TestScenario<T> value, covariant Object? memento) Future<void>
A function that is guaranteed to be called after a value is tested, even if it throws an exception.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited