TestScenarioVariant<T> class
Methods
-
describeValue(TestScenario<T> value)
→ String
-
Returns the string that will be used to both add to the test description, and
be printed when a test fails for this variation.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setUp(TestScenario<T> value)
→ Future<void>
-
A function that will be called before each value is tested, with the
value that will be tested.
override
-
tearDown(TestScenario<T> value, covariant Object? memento)
→ Future<void>
-
A function that is guaranteed to be called after a value is tested, even
if it throws an exception.
override
-
toString()
→ String
-
A string representation of this object.
inherited