describeValue method
Returns the string that will be used to both add to the test description, and be printed when a test fails for this variation.
Implementation
@override
String describeValue(TestScenario<T> value) {
return value.description;
}
Returns the string that will be used to both add to the test description, and be printed when a test fails for this variation.
@override
String describeValue(TestScenario<T> value) {
return value.description;
}